/* 
 * File:   lcd4bit.h
 * Author: chengo_cc
 *
 * Created on 12 April 2016, 12:52 PM
 */

#ifndef LCD4BIT_H
//------------------------------------------------------------------------------
#include "prototypes_lcd.h"
//---------------------------Screen Commands------------------------------------
#define display_on      0x0C      //Cursor OFF, Blink off
#define display_off     0x08
#define cursor_on       0x0E
#define cursor_blink    0x0F
#define home            0x02
#define clear           0x01
#define auto_increment  0x06
#define auto_decrement  0x04
#define function_set    0x28 //DL = 0 <Data Lenghth> (4 bit mode). N = 1 <Num lines> (2 Lines).
#define font2           function_set | 0x04     //Set bit 3 only.
//-----------------------Follow Datasheet instructions--------------------------
void LCD_init()
{
  RS_dir = 0;
  EN_dir = 0;
  D4_dir = 0;
  D5_dir = 0;
  D6_dir = 0;
  D7_dir = 0;

  LCD_command(home);
  LCD_command(function_set);
  LCD_command(display_on);
  LCD_command(auto_increment);
}
//------------------------------------------------------------------------------
void LCD_write(char data)
{
  D4 = ( (data>>0) & 0x01 );
  D5 = ( (data>>1) & 0x01 );
  D6 = ( (data>>2) & 0x01 );
  D7 = ( (data>>3) & 0x01 );
}
//------------------------------------------------------------------------------
void LCD_command(char command)
{
  RS = 0;                                   //Instruction register ( commands ).
  LCD_write(command >> 4);                  //Higher Nibble
  latch();
  LCD_write(command & 0x0F);                //Lower Nibble
  latch();
}
//------------------------------------------------------------------------------
void LCD_data(char data)
{
  RS = 1;                           //Data register  ( Strings and characters ).
  LCD_write(data >> 4);
  latch();
  LCD_write(data & 0x0F);
  latch();
}
//------------------------------------------------------------------------------
void LCD_string(char row, char column, char text[])
{
  LCD_command(screenPos[row][column]);  //Set co-ordinate.
  while(*text)
  {
    LCD_data( *text++ );
  }
}
//------------------------------------------------------------------------------
void LCD_character(char row, char column, char character)
{
  LCD_command(screenPos[row][column]);
  LCD_data(character);
}
//------------------------------------------------------------------------------
void latch()
{
  EN  = 1;
  delay(1);
  EN  = 0;
}
//------------------------------------------------------------------------------
#define	LCD4BIT_H

#ifdef	__cplusplus
extern "C" {
#endif




#ifdef	__cplusplus
}
#endif

#endif	/* LCD4BIT_H */